==> haskell-roman-numerals-0.5.1.5-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-2sQvt9jE6VcKkNvVB8KsD3
key:                  roman-numerals-0.5.1.5-2sQvt9jE6VcKkNvVB8KsD3
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  83d940245ee2e9a20f02244ab2905d46
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-9.0.2/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/roman-numerals-0.5.1.5
hs-libraries:         HSroman-numerals-0.5.1.5-2sQvt9jE6VcKkNvVB8KsD3
depends:
    base-4.15.1.0 base-unicode-symbols-0.2.4.2-3I3pSMQwGEB5P9J2UkMzWs
    bytestring-0.10.12.1 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-roman-numerals-0.5.1.5-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-roman-numerals.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 roman-numerals
version:              0.5.1.5
visibility:           public
id:                   roman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
key:                  roman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
license:              BSD-3-Clause
copyright:            2009–2014 Roel van Dijk
maintainer:           Roel van Dijk <vandijk.roel@gmail.com>
author:               Roel van Dijk <vandijk.roel@gmail.com>
stability:            stable
homepage:             https://github.com/roelvandijk/roman-numerals
synopsis:             Parsing and pretty printing of Roman numerals
description:
    This library provides functions for parsing and pretty printing
    Roman numerals. Because the notation of Roman numerals has varied
    through the centuries this package allows for some customisation
    using a configuration that is passed to the conversion functions.

category:             Numerical, Parsing
abi:                  6e93fb8245a17b5e51c7c7baf1ea83d1
exposed:              True
exposed-modules:      Text.Numeral.Roman
import-dirs:          /usr/lib/ghc-9.2.8/site-local/roman-numerals-0.5.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/roman-numerals-0.5.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-roman-numerals
hs-libraries:         HSroman-numerals-0.5.1.5-Ky2Li6P3sYXDMxeR51IilI
depends:
    base-4.16.4.0 base-unicode-symbols-0.2.4.2-LxaiYZxX2IHCdJ6KOk7ePF
    bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-roman-numerals/html/roman-numerals.haddock

haddock-html:         /usr/share/doc/haskell-roman-numerals/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
